import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

var width = 800;
var height = 220;

//redering svg tag from html
const svg = d3
    .select('body')
    .select('#Plot2')
    .append('svg')
    .attr('width', width)
    .attr('height', height);

svg.append('g')
  .attr(
    'transform','translate(' + width + ',' + height + ')' );

const update = data => { 
  const xValue = function(d) { return d.date; }; //display dates on x axis
  const xAxisLabel = 'Date';
  
  const yValue = function(d) { return +d.nb_musique; }; //display salees value on y axis
  const yAxisLabel = 'Nb Musiques';

  
  //center g in svg
  const g = svg.append('g')
    .attr('transform', `translate(${width/2},${height/3})`);
  
  
  // group the data: I want to draw one line per group
  var sumstat = d3.nest() // nest function allows to group the calculation per level of a factor
    .key(function(d) { return d.genre;})
    .entries(data);

  // Add X axis --> it is a date format
  const xScale = d3.scaleTime()
    .domain(d3.extent(data, xValue))
    .range([ 0, width/2.1 ])
  	.nice();
  
  //creating xAxis  
  const xAxis = d3.axisBottom(xScale)
    .tickSize(-height/2)
    .tickPadding(15);

  // Add Y axis
  const yScale = d3.scaleLinear()
    .domain([0, d3.max(data, yValue)])
    .range([ height/2, 0 ])
  	.nice();
  
  //creating yAxis  
  const yAxis = d3.axisLeft(yScale)
    .tickSize(-width/2)
    .tickPadding(10)
  
	//Appending Y axis label to svg
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  	yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -50)
      .attr('x', 0)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  //Appending X axis label to svg
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${height/2})`);
  
  xAxisG.select('.domain').remove();
  
   xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', width / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  // color palette
  var res = sumstat.map(function(d){ return d.key }) // list of group names
  var color = d3.scaleOrdinal()
    .domain(res)
    .range(['#e41a1c','#377eb8','#4daf4a','#984ea3','#ff7f00','#ffff33','#a65628','#f781bf','#999999'])


  // Draw the line
  g.selectAll(".line")
      .data(sumstat)
      .enter()
      .append("path")
        .attr("fill", "none")
        .attr("stroke", function(d){ return color(d.key) })
        .attr("stroke-width", 1.5)
        .attr("d", function(d){
          return d3.line()
            .x(function(d) { return xScale(d.date); })
            .y(function(d) { return yScale(+d.nb_musique) ; })
            (d.values)
        })
    
};



let newData = new Array();
d3.json("album.json").then((data) => { 
  
    data.forEach(function(d){
    
    
      
    let isPresent = false;
    let index = null;

    if (d.genre != '') {
    	if (d.dateRelease != null){

        let date = new Date(d.dateRelease);
      
        newData.forEach(function(dd){          
        	if(dd.genre === d.genre){
            if(dd.date.getFullYear() === date.getFullYear()){
              isPresent = true;
              index = dd.id;
            }
          }     
        });
        if(isPresent){
          newData[index].nb_musique = newData[index].nb_musique + 1;
        }
        else{
          newData.push({
                 "id": newData.length,
                 "genre": d.genre,
                 "date" : date,
                 "nb_musique" : 1
          }); 
        }
      }
    }
      
    
  });
  //Trier les dates par ordre croissant 
  	newData.sort(function (a, b) {
            return d3['ascending'](
              +a.date,
              +b.date
            );
    })
  	update(newData);
});
